package betterquesting.client.gui2.editors;

import betterquesting.api.client.gui.misc.INeedsRefresh;
import betterquesting.api.client.gui.misc.IVolatileScreen;
import betterquesting.api.enums.EnumQuestVisibility;
import betterquesting.api.properties.NativeProps;
import betterquesting.api.questing.IQuestLine;
import betterquesting.api.utils.BigItemStack;
import betterquesting.api2.client.gui.GuiScreenCanvas;
import betterquesting.api2.client.gui.controls.PanelButton;
import betterquesting.api2.client.gui.controls.PanelButtonStorage;
import betterquesting.api2.client.gui.controls.PanelTextField;
import betterquesting.api2.client.gui.controls.filters.FieldFilterString;
import betterquesting.api2.client.gui.events.IPEventListener;
import betterquesting.api2.client.gui.events.PEventBroadcaster;
import betterquesting.api2.client.gui.events.PanelEvent;
import betterquesting.api2.client.gui.events.types.PEventButton;
import betterquesting.api2.client.gui.misc.GuiAlign;
import betterquesting.api2.client.gui.misc.GuiPadding;
import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.misc.GuiTransform;
import betterquesting.api2.client.gui.panels.CanvasEmpty;
import betterquesting.api2.client.gui.panels.CanvasTextured;
import betterquesting.api2.client.gui.panels.bars.PanelVScrollBar;
import betterquesting.api2.client.gui.panels.content.PanelLine;
import betterquesting.api2.client.gui.panels.content.PanelTextBox;
import betterquesting.api2.client.gui.panels.lists.CanvasScrolling;
import betterquesting.api2.client.gui.themes.presets.PresetColor;
import betterquesting.api2.client.gui.themes.presets.PresetIcon;
import betterquesting.api2.client.gui.themes.presets.PresetLine;
import betterquesting.api2.client.gui.themes.presets.PresetTexture;
import betterquesting.api2.storage.DBEntry;
import betterquesting.api2.utils.QuestTranslation;
import betterquesting.client.gui2.editors.designer.GuiDesigner;
import betterquesting.client.gui2.editors.nbt.GuiItemSelection;
import betterquesting.network.handlers.NetChapterEdit;
import betterquesting.questing.QuestLineDatabase;
import java.util.List;
import net.minecraft.client.gui.GuiScreen;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import org.lwjgl.input.Keyboard;
import org.lwjgl.util.vector.Vector4f;

/* loaded from: betterquesting_client_gui2_editors.jar:betterquesting/client/gui2/editors/GuiQuestLinesEditor.class */
public class GuiQuestLinesEditor extends GuiScreenCanvas implements IPEventListener, IVolatileScreen, INeedsRefresh {
    private CanvasScrolling lineList;
    private PanelTextField<String> tfName;
    private PanelTextField<String> tfDesc;
    private PanelButton btnDesign;
    private PanelButton btnVis;
    private PanelButton btnIcon;
    private IQuestLine selected;
    private int selID;

    public GuiQuestLinesEditor(GuiScreen parent) {
        super(parent);
        this.selID = -1;
    }

    public void refreshGui() {
        if (this.selID >= 0) {
            this.selected = (IQuestLine) QuestLineDatabase.INSTANCE.getValue(this.selID);
            if (this.selected == null) {
                this.selID = -1;
                this.btnDesign.setActive(false);
                this.btnIcon.setActive(false);
                this.btnVis.setActive(false);
                this.tfName.setText("");
                this.tfDesc.setText("");
            } else {
                this.btnDesign.setActive(true);
                this.btnIcon.setActive(true);
                this.btnVis.setActive(true);
                this.btnVis.setText(QuestTranslation.translate("betterquesting.btn.show", new Object[0]) + ": " + this.selected.getProperty(NativeProps.VISIBILITY));
                if (!this.tfName.isFocused()) {
                    this.tfName.setText(this.selected.getUnlocalisedName());
                }
                if (!this.tfDesc.isFocused()) {
                    this.tfDesc.setText(this.selected.getUnlocalisedDescription());
                }
            }
        }
        reloadList();
    }

    public void initPanel() {
        super.initPanel();
        PEventBroadcaster.INSTANCE.register(this, PEventButton.class);
        Keyboard.enableRepeatEvents(true);
        CanvasTextured cvBackground = new CanvasTextured(new GuiTransform(GuiAlign.FULL_BOX, new GuiPadding(0, 0, 0, 0), 0), PresetTexture.PANEL_MAIN.getTexture());
        addPanel(cvBackground);
        PanelTextBox panTxt = new PanelTextBox(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 16, 0, -32), 0), QuestTranslation.translate("betterquesting.title.edit_line1", new Object[0])).setAlignment(1);
        panTxt.setColor(PresetColor.TEXT_HEADER.getColor());
        cvBackground.addPanel(panTxt);
        cvBackground.addPanel(new PanelButton(new GuiTransform(GuiAlign.BOTTOM_CENTER, -100, -16, 200, 16, 0), 0, QuestTranslation.translate("gui.back", new Object[0])));
        this.lineList = new CanvasScrolling(new GuiTransform(GuiAlign.HALF_LEFT, new GuiPadding(16, 32, 16, 48), 0));
        cvBackground.addPanel(this.lineList);
        PanelVScrollBar scList = new PanelVScrollBar(new GuiTransform(new Vector4f(0.5f, 0.0f, 0.5f, 1.0f), new GuiPadding(-16, 32, 8, 48), 0));
        cvBackground.addPanel(scList);
        this.lineList.setScrollDriverY(scList);
        PanelButton btnAdd = new PanelButton(new GuiTransform(new Vector4f(0.0f, 1.0f, 0.25f, 1.0f), new GuiPadding(16, -40, 0, 24), 0), 1, QuestTranslation.translate("betterquesting.btn.new", new Object[0]));
        cvBackground.addPanel(btnAdd);
        PanelButton btnImport = new PanelButton(new GuiTransform(new Vector4f(0.25f, 1.0f, 0.5f, 1.0f), new GuiPadding(0, -40, 16, 24), 0), 2, QuestTranslation.translate("betterquesting.btn.import", new Object[0]));
        cvBackground.addPanel(btnImport);
        CanvasEmpty cvRight = new CanvasEmpty(new GuiTransform(GuiAlign.HALF_RIGHT, new GuiPadding(8, 32, 16, 24), 0));
        cvBackground.addPanel(cvRight);
        PanelTextBox txtName = new PanelTextBox(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 4, 0, -16), 0), QuestTranslation.translate("betterquesting.gui.name", new Object[0]));
        txtName.setColor(PresetColor.TEXT_MAIN.getColor());
        cvRight.addPanel(txtName);
        this.tfName = new PanelTextField<>(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 16, 0, -32), 0), "", FieldFilterString.INSTANCE);
        cvRight.addPanel(this.tfName);
        PanelTextBox txtDesc = new PanelTextBox(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 36, 0, -48), 0), QuestTranslation.translate("betterquesting.gui.description", new Object[0]));
        txtDesc.setColor(PresetColor.TEXT_MAIN.getColor());
        cvRight.addPanel(txtDesc);
        this.tfDesc = new PanelTextField<>(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 48, 16, -64), 0), "", FieldFilterString.INSTANCE);
        this.tfDesc.setMaxLength(Integer.MAX_VALUE);
        cvRight.addPanel(this.tfDesc);
        this.btnIcon = new PanelButton(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 80, 0, -96), 0), -1, QuestTranslation.translate("betterquesting.btn.icon", new Object[0])) { // from class: betterquesting.client.gui2.editors.GuiQuestLinesEditor.1
            public void onButtonClick() {
                if (GuiQuestLinesEditor.this.selected == null) {
                    return;
                }
                GuiQuestLinesEditor.this.field_146297_k.func_147108_a(new GuiItemSelection(GuiQuestLinesEditor.this, (BigItemStack) GuiQuestLinesEditor.this.selected.getProperty(NativeProps.ICON), value -> {
                    GuiQuestLinesEditor.this.selected.setProperty(NativeProps.ICON, value);
                    GuiQuestLinesEditor.this.SendChanges(new DBEntry(GuiQuestLinesEditor.this.selID, GuiQuestLinesEditor.this.selected));
                }));
            }
        };
        this.btnIcon.setActive(this.selected != null);
        cvRight.addPanel(this.btnIcon);
        this.btnVis = new PanelButton(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 96, 0, -112), 0), -1, QuestTranslation.translate("betterquesting.btn.show", new Object[0]) + ": " + (this.selected == null ? EnumQuestVisibility.NORMAL : (EnumQuestVisibility) this.selected.getProperty(NativeProps.VISIBILITY))) { // from class: betterquesting.client.gui2.editors.GuiQuestLinesEditor.2
            public void onButtonClick() {
                if (GuiQuestLinesEditor.this.selected == null) {
                    return;
                }
                EnumQuestVisibility[] visList = EnumQuestVisibility.values();
                EnumQuestVisibility vis = visList[(((EnumQuestVisibility) GuiQuestLinesEditor.this.selected.getProperty(NativeProps.VISIBILITY)).ordinal() + 1) % visList.length];
                GuiQuestLinesEditor.this.selected.setProperty(NativeProps.VISIBILITY, vis);
                setText(QuestTranslation.translate("betterquesting.btn.show", new Object[0]) + ": " + vis);
            }
        };
        this.btnVis.setActive(this.selected != null);
        cvRight.addPanel(this.btnVis);
        PanelButton btnManage = new PanelButton(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 112, 0, -128), 0), 3, QuestTranslation.translate("betterquesting.btn.add_remove_quests", new Object[0]));
        cvRight.addPanel(btnManage);
        this.btnDesign = new PanelButton(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 96, 0, -112), 0), 4, QuestTranslation.translate("betterquesting.btn.designer", new Object[0]));
        this.btnDesign.setActive(this.selected != null);
        cvRight.addPanel(this.btnDesign);
        PanelButton btnTextEditor = new PanelButton(new GuiTransform(GuiAlign.TOP_RIGHT, new GuiPadding(-16, 48, 0, -64), 0), 8, "Aa");
        cvRight.addPanel(btnTextEditor);
        GuiTransform guiTransform = new GuiTransform(GuiAlign.TOP_CENTER, 0, 32, 0, 0, 0);
        guiTransform.setParent(cvBackground.getTransform());
        GuiTransform guiTransform2 = new GuiTransform(GuiAlign.BOTTOM_CENTER, 0, -24, 0, 0, 0);
        guiTransform2.setParent(cvBackground.getTransform());
        PanelLine paLine0 = new PanelLine(guiTransform, guiTransform2, PresetLine.GUI_DIVIDER.getLine(), 1, PresetColor.GUI_DIVIDER.getColor(), 1);
        cvBackground.addPanel(paLine0);
        if (this.selID >= 0) {
            this.selected = (IQuestLine) QuestLineDatabase.INSTANCE.getValue(this.selID);
            if (this.selected == null) {
                this.selID = -1;
                this.btnDesign.setActive(false);
                this.btnIcon.setActive(false);
                this.btnVis.setActive(false);
                this.tfName.setText("");
                this.tfDesc.setText("");
            } else {
                this.btnDesign.setActive(true);
                this.btnIcon.setActive(true);
                this.btnVis.setActive(true);
                if (!this.tfName.isFocused()) {
                    this.tfName.setText(this.selected.getUnlocalisedName());
                }
                if (!this.tfDesc.isFocused()) {
                    this.tfDesc.setText(this.selected.getUnlocalisedDescription());
                }
            }
        }
        reloadList();
    }

    public boolean onMouseClick(int mx, int my, int click) {
        if (this.selected != null) {
            boolean changed = false;
            if (!((String) this.tfName.getValue()).equals(this.selected.getUnlocalisedName())) {
                this.selected.setProperty(NativeProps.NAME, this.tfName.getValue());
                changed = true;
            }
            if (!((String) this.tfDesc.getValue()).equals(this.selected.getUnlocalisedDescription())) {
                this.selected.setProperty(NativeProps.DESC, this.tfDesc.getValue());
                changed = true;
            }
            if (changed) {
                SendChanges(new DBEntry<>(this.selID, this.selected));
            }
        }
        return super.onMouseClick(mx, my, click);
    }

    public void onPanelEvent(PanelEvent event) {
        if (event instanceof PEventButton) {
            onButtonPress((PEventButton) event);
        }
    }

    private void onButtonPress(PEventButton event) {
        PanelButtonStorage button = event.getButton();
        if (button.getButtonID() == 0) {
            this.field_146297_k.func_147108_a(this.parent);
            return;
        }
        if (button.getButtonID() == 1) {
            NBTTagCompound payload = new NBTTagCompound();
            NBTTagList dataList = new NBTTagList();
            NBTTagCompound entry = new NBTTagCompound();
            entry.func_74768_a("chapterID", -1);
            dataList.func_74742_a(entry);
            payload.func_74782_a("data", dataList);
            payload.func_74768_a("action", 3);
            NetChapterEdit.sendEdit(payload);
            return;
        }
        if (button.getButtonID() == 2) {
            this.field_146297_k.func_147108_a(new GuiImporters(this));
            return;
        }
        if (button.getButtonID() == 3) {
            this.field_146297_k.func_147108_a(new GuiQuestLineAddRemove(this, this.selected));
            return;
        }
        if (button.getButtonID() == 4 && this.selected != null) {
            this.field_146297_k.func_147108_a(new GuiDesigner(this, this.selected));
            return;
        }
        if (button.getButtonID() == 5 && (button instanceof PanelButtonStorage)) {
            DBEntry<IQuestLine> entry2 = (DBEntry) button.getStoredValue();
            this.selected = (IQuestLine) entry2.getValue();
            this.selID = entry2.getID();
            this.tfName.setText(this.selected.getUnlocalisedName());
            this.tfDesc.setText(this.selected.getUnlocalisedDescription());
            this.btnDesign.setActive(true);
            this.btnIcon.setActive(true);
            this.btnVis.setActive(true);
            this.btnVis.setText(QuestTranslation.translate("betterquesting.btn.show", new Object[0]) + ": " + this.selected.getProperty(NativeProps.VISIBILITY));
            reloadList();
            return;
        }
        if (button.getButtonID() == 6 && (button instanceof PanelButtonStorage)) {
            DBEntry<IQuestLine> entry3 = (DBEntry) button.getStoredValue();
            NBTTagCompound payload2 = new NBTTagCompound();
            payload2.func_74783_a("chapterIDs", new int[]{entry3.getID()});
            payload2.func_74768_a("action", 1);
            NetChapterEdit.sendEdit(payload2);
            return;
        }
        if (button.getButtonID() != 7 || !(button instanceof PanelButtonStorage)) {
            if (button.getButtonID() == 8) {
                this.field_146297_k.func_147108_a(new GuiTextEditor(this, this.tfDesc.getRawText(), value -> {
                    if (this.selected != null) {
                        this.tfDesc.setText(value);
                        this.selected.setProperty(NativeProps.DESC, value);
                        SendChanges(new DBEntry<>(this.selID, this.selected));
                    }
                }));
            }
        } else {
            DBEntry<IQuestLine> entry4 = (DBEntry) button.getStoredValue();
            int order = QuestLineDatabase.INSTANCE.getOrderIndex(entry4.getID());
            if (order > 0) {
                SendReorder(order);
            }
        }
    }

    private void reloadList() {
        this.lineList.resetCanvas();
        int w = this.lineList.getTransform().getWidth();
        int i = 0;
        for (DBEntry<IQuestLine> entry : QuestLineDatabase.INSTANCE.getSortedEntries()) {
            IQuestLine ql = (IQuestLine) entry.getValue();
            PanelButtonStorage<DBEntry<IQuestLine>> tmp = new PanelButtonStorage<>(new GuiRectangle(0, i * 16, w - 32, 16, 0), 5, QuestTranslation.translate(ql.getUnlocalisedName(), new Object[0]), entry);
            tmp.setActive(entry.getID() != this.selID);
            this.lineList.addPanel(tmp);
            this.lineList.addPanel(new PanelButtonStorage(new GuiRectangle(w - 32, i * 16, 16, 16, 0), 6, "", entry).setIcon(PresetIcon.ICON_TRASH.getTexture()));
            this.lineList.addPanel(new PanelButtonStorage(new GuiRectangle(w - 16, i * 16, 16, 16, 0), 7, "", entry).setIcon(PresetIcon.ICON_UP.getTexture()));
            i++;
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void SendChanges(DBEntry<IQuestLine> chapter) {
        NBTTagCompound payload = new NBTTagCompound();
        NBTTagList dataList = new NBTTagList();
        NBTTagCompound entry = new NBTTagCompound();
        entry.func_74768_a("chapterID", chapter.getID());
        entry.func_74782_a("config", ((IQuestLine) chapter.getValue()).writeToNBT(new NBTTagCompound(), (List) null));
        dataList.func_74742_a(entry);
        payload.func_74782_a("data", dataList);
        payload.func_74768_a("action", 0);
        NetChapterEdit.sendEdit(payload);
    }

    private void SendReorder(int indexToShift) {
        if (indexToShift <= 0) {
            return;
        }
        List<DBEntry<IQuestLine>> entries = QuestLineDatabase.INSTANCE.getSortedEntries();
        if (indexToShift >= entries.size()) {
            return;
        }
        int[] chapterIDs = new int[entries.size()];
        for (int i = 0; i < entries.size(); i++) {
            chapterIDs[i] = entries.get(i).getID();
        }
        int tmp = chapterIDs[indexToShift];
        chapterIDs[indexToShift] = chapterIDs[indexToShift - 1];
        chapterIDs[indexToShift - 1] = tmp;
        NBTTagCompound payload = new NBTTagCompound();
        payload.func_74783_a("chapterIDs", chapterIDs);
        payload.func_74768_a("action", 2);
        NetChapterEdit.sendEdit(payload);
    }
}
